utils

package
v1.2.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: MIT Imports: 3 Imported by: 0

README

Utils

General-purpose utility functions for path resolution and system checks.

Includes:

  • Graceful executable path resolution
  • Terminal interactivity (TTY) checks
  • Built-in installation instructions for common tools

For detailed documentation and usage examples, see the Utils Component Documentation.

Documentation

Index

Constants

const (
	InstructionKubectl    = "For instructions on how to install kubectl see: https://kubernetes.io/docs/tasks/tools/"
	InstructionAz         = "For instructions on how to install the Azure CLI see: https://docs.microsoft.com/en-us/cli/azure/install-azure-cli"
	InstructionKubelogin  = "For instructions on how to install kubelogin see: https://azure.github.io/kubelogin/install.html"
	InstructionTerraform  = "For instructions on how to install Terraform see: https://learn.hashicorp.com/tutorials/terraform/install-cli"
	InstructionTerragrunt = "For instructions on how to install Terragrunt see: https://terragrunt.gruntwork.io/docs/getting-started/install/"
	InstructionAws        = "" /* 129-byte string literal not displayed */
	InstructionGit        = "For instructions on how to install Git see: https://git-scm.com/book/en/v2/Getting-Started-Installing-Git"
	InstructionGh         = "For instructions on how to install the GitHub CLI see: https://github.com/cli/cli#installation"
)

Variables

var (
	Instructions = map[string]string{
		"kubectl":    InstructionKubectl,
		"az":         InstructionAz,
		"kubelogin":  InstructionKubelogin,
		"terraform":  InstructionTerraform,
		"terragrunt": InstructionTerragrunt,
		"aws":        InstructionAws,
		"git":        InstructionGit,
		"gh":         InstructionGh,
	}
)

Functions

func GracefulGetPath

func GracefulGetPath(name string, logger *log.Logger, instructions ...string) (string, error)

func IsInteractive

func IsInteractive() bool

Types

This section is empty.

Jump to